library(Seurat)
library(SeuratDisk)
library(ggplot2)
library(patchwork)

# Read in 10X data
ids = c("1_4mths", "3_4mths", "4_4mths", "5_8mths", "6_8mths", "7_8mths", "8_8mths", "ES004_1_1", "ES004_1_2", "ES004_2_1", "ES004_2_2")
for( library_id in ids){ 
  setwd(library_id)
  results = read.table("combined_results_w_combined_assignments.tsv", header=T)
  pbmc.data <- Read10X(data.dir = paste0(library_id, "/sample_filtered_feature_bc_matrix/") # adjust depending on data file structure
  pbmc <- CreateSeuratObject(counts = pbmc.data, project = "longcovid", min.cells = 3, min.features = 200)
  pbmc[["percent.mt"]] <- PercentageFeatureSet(pbmc, pattern = "^MT-")
  pbmc[["UMI"]]  <- rownames(pbmc@meta.data)
                       
  # Assign timepoints
  if( grepl("4mths", library_id) ) { timepoint = "4months"}
  if( grepl("8mths", library_id) ) { timepoint = "8months"}
  if( grepl("^ES", library_id) ) { timepoint = "24months"}
  pbmc[["timepoint"]]  <- timepoint


  # Plot                       
  png(paste0(file, ".qc.png"), width=1000)
  VlnPlot(pbmc, features = c("nFeature_RNA", "nCount_RNA", "percent.mt"), ncol = 3)
  dev.off()
                       
  # Assign cells 
  m = match( pbmc$UMI, results[,1] )
  f.b = !is.na(m)
  f.r = m[f.b]
  pbmc@meta.data = cbind(pbmc@meta.data, results[f.r,-1])

  # Assign phenotpes 
  m = match(  pbmc@meta.data$Demuxlet_Individual_Assignment, phens[,1])
  pbmc@meta.data = cbind( pbmc@meta.data, phens[m,])
  pbmc[["batch"]] <- "rep 1"
  pbmc[["batch""][grepl("_2$|^4_|^6_|^8_",  pbmc[["orig.ident"]])] = "rep 2"

                       
  saveRDS(pbmc, file=paste0(library_id, ".rds"))

  setwd("../")
}

# Load and process all data  
for( library_id in ids){ 
  pbmc - readRDS(file=paste0(library_id, "/", library_id, ".rds"))                       
  pbmc = subset(pbmc, subset = nFeature_RNA > 200 & nFeature_RNA < 2500 & percent.mt < 5)
  pbmc <- SCTransform(pbmc, vars.to.regress = "percent.mt", verbose = FALSE)
  pbmc <- RunPCA(pbmc, verbose = FALSE)
  pbmc <- RunUMAP(pbmc, dims = 1:30, verbose = FALSE)
  pbmc <- FindNeighbors(pbmc, dims = 1:30, verbose = FALSE)
  pbmc <- FindClusters(pbmc, verbose = FALSE)
  pbmc.list[[library_id]] = pbmc
} 
                       
features <- SelectIntegrationFeatures(object.list = pbmc.list, nfeatures = 3000)
pbmc.list <- PrepSCTIntegration(object.list = pbmc.list, anchor.features = features)
immune.anchors <- FindIntegrationAnchors(object.list = pbmc.list, normalization.method = "SCT",
    anchor.features = features)
immune.combined.sct <- IntegrateData(anchorset = immune.anchors, normalization.method = "SCT")               

                       
saveRDS(immune.combined.sct,   file = "combined_SCT.rds")

# Load reference 
ref_loc = "azimuth/human_pbmc/pbmc_multimodal.h5seurat"
reference <- LoadH5Seurat(ref_loc)
#reference <- reference$map 
#reference <- FindVariableFeatures(reference)
#reference <- ScaleData(reference, features = rownames(reference))
#reference <- RunPCA(reference, features = VariableFeatures(object = reference))

# Genes in common between your cells (obj) and the reference 
common = intersect(rownames(obj), rownames(reference))

# Find anchors between data
anchors <- FindTransferAnchors(
  reference = reference,
  query = obj,
  normalization.method = "SCT",
   reference.reduction = "refDR",
  dims = 1:50,
  features = common
)


obj <- MapQuery(
  anchorset = anchors,
  query = obj,
  reference = reference,
  refdata = list(
    celltype.l1 = "celltype.l1",
    celltype.l2 = "celltype.l2",
    celltype.l3 = "celltype.l3",
    predicted_ADT = "ADT"
  ),
    reference.reduction = "refDR" #,
 # reduction.model = "umap"
)




                       
